==> source-highlight-1.2.1.tar.gz: source-highlight-1.2.1/src/lib/textgen.h <==
/*
** Copyright (C) 1999, 2000, 2001 Lorenzo Bettini <bettini@gnu.org>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

// textgen.h : Text Generator class

#ifndef _TEXTGEN_H
#define _TEXTGEN_H

class CharTranslator;

class TextGenerator
{
 protected:
  CharTranslator *char_translator;

 public:
  TextGenerator(CharTranslator *);

  virtual void generate( const char *s ) const;
  virtual void generate( const char *s, int start, int end ) const;
  virtual void generate_preproc(const char *s) const;

  virtual void generateln( const char *s ) const;

  virtual void generateEntire( const char *s ) const;

  virtual void startTextGeneration() const {}
  virtual void endTextGeneration() const {}
  virtual void beginText( const char *s ) const;
  virtual void endText( const char *s ) const;
} ;

// Decorator
class TextDecorator : public TextGenerator
{
 protected:
  TextGenerator *decorated ;
  
 public:
  TextDecorator( TextGenerator *t, CharTranslator * );

  virtual void startTextGeneration() const;
  virtual void endTextGeneration() const;

  // pure virtual functions
  virtual void startDecorate() const = 0 ;
  virtual void endDecorate() const = 0 ;
} ;

#endif

==> source-highlight-1.3.tar.gz: source-highlight-1.3/src/lib/textgen.h <==
/*
** Copyright (C) 1999, 2000, 2001 Lorenzo Bettini <bettini@gnu.org>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

// textgen.h : Text Generator class

#ifndef _TEXTGEN_H
#define _TEXTGEN_H

class CharTranslator;

class TextGenerator
{
 protected:
  CharTranslator *char_translator;

 public:
  TextGenerator(CharTranslator *);

  virtual void generate( const char *s );
  virtual void generate( const char *s, int start, int end );
  virtual void generate_preproc(const char *s);

  virtual void generateln( const char *s );

  virtual void generateEntire( const char *s );

  virtual void startTextGeneration() {}
  virtual void endTextGeneration() {}
  virtual void beginText( const char *s );
  virtual void endText( const char *s );
} ;

// Decorator
class TextDecorator : public TextGenerator
{
 protected:
  TextGenerator *decorated ;
  
 public:
  TextDecorator( TextGenerator *t, CharTranslator * );

  virtual void startTextGeneration();
  virtual void endTextGeneration();

  // pure virtual functions
  virtual void startDecorate() = 0 ;
  virtual void endDecorate() = 0 ;
} ;

#endif
